==> amule_2.0.3.orig.tar.gz: amule-2.0.3/src/KadDlg.h <==
//
// This file is part of the aMule Project.
//
// Copyright (c) 2003-2005 aMule Team ( admin@amule.org / http://www.amule.org )
// Copyright (c) 2004-2005 Angel Vidal (Kry) ( kry@amule.org / http://www.amule.org )
//
// Any parts of this program derived from the xMule, lMule or eMule project,
// or contributed by third-party developers are copyrighted by their
// respective authors.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA, 02111-1307, USA
//

#ifndef KADDLG_H
#define KADDLG_H

#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
#pragma interface "KadDlg.h"
#endif

#include <wx/defs.h>		// Needed before any other wx/*.h
#include <wx/panel.h>		// Needed for wxPanel
#include "Types.h"

class CMD4Hash;
class wxListCtrl;	
class wxListEvent;
class wxCommandEvent;
class wxMouseEvent;

class CKadDlg : public wxPanel {
public:
	CKadDlg(wxWindow* pParent);   
	~CKadDlg() {};

	void AddNode(uint32 ip, uint16 port, CMD4Hash Hash);
	void RemoveNode();
		
private:

	wxListCtrl* NodesList;
	wxListCtrl* CurrentKadSearches;
		
	// Event handlers
	void		OnBnClickedBootstrapClient(wxCommandEvent& evt);
	void		OnBnClickedBootstrapKnown(wxCommandEvent& evt);
	void		OnNodeListItemSelected(wxListEvent& evt);
	void		OnKadSearchListItemSelected(wxListEvent& evt);
	void		OnFieldsChange(wxCommandEvent& evt);
	void		OnRMButton(wxMouseEvent& evt);

	DECLARE_EVENT_TABLE()
};

#endif // KADDLG_H

==> amule_2.2.1.orig.tar.gz: amule-2.2.1.orig/src/KadDlg.h <==
//
// This file is part of the aMule Project.
//
// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
// Copyright (c) 2004-2008 Angel Vidal (Kry) ( kry@amule.org / http://www.amule.org )
//
// Any parts of this program derived from the xMule, lMule or eMule project,
// or contributed by third-party developers are copyrighted by their
// respective authors.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
//

#ifndef KADDLG_H
#define KADDLG_H

#include <wx/panel.h>		// Needed for wxPanel

class COScopeCtrl;	
class wxListEvent;
class wxCommandEvent;
class wxMouseEvent;
typedef struct UpdateInfo GraphUpdateInfo;
	

class CKadDlg : public wxPanel
{
public:
	CKadDlg(wxWindow* pParent);   
	~CKadDlg() {};
	
	void Init();
	void SetUpdatePeriod(int step);
	void SetGraphColors();
	void UpdateGraph(const GraphUpdateInfo& update);
		
private:
	COScopeCtrl* m_kad_scope;

	// Event handlers
	void		OnBnClickedBootstrapClient(wxCommandEvent& evt);
	void		OnBnClickedBootstrapKnown(wxCommandEvent& evt);
	void		OnBnClickedDisconnectKad(wxCommandEvent& evt);
	void		OnBnClickedUpdateNodeList(wxCommandEvent& evt);
	void		OnFieldsChange(wxCommandEvent& evt);

	DECLARE_EVENT_TABLE()
};

#endif // KADDLG_H
// File_checked_for_headers
